@@ -1,6 +1,7 @@
 """Miscelleneous controls."""
 
 import textwrap
+from pathlib import Path
 
 import tf2mon
 from tf2mon.control import Control
@@ -14,7 +15,7 @@ class HelpControl(Control):
     def handler(self, _match) -> None:
 
         tf2mon.ui.show_journal("help", " Function Keys ".center(80, "-"))
-        for line in tf2mon.controls.fkey_help().splitlines():
+        for line in tf2mon.controller.fkey_help().splitlines():
             tf2mon.ui.show_journal("help", line)
 
         tf2mon.ui.show_journal("help", " Admin Commands ".center(80, "-"))
@@ -42,11 +43,14 @@ class MotdControl(Control):
     """Display Message of the Day."""
 
     name = "MOTD"
+    _path: Path = None
+
+    def start(self) -> None:
+        self._path = tf2mon.options.tf2_install_dir / "cfg" / "motd.txt"
 
     def handler(self, _match) -> None:
-        motd = tf2mon.monitor.tf2_scripts_dir.parent / "motd.txt"
-        tf2mon.ui.show_journal("help", f" {motd} ".center(80, "-"))
+        tf2mon.ui.show_journal("help", f" {self._path} ".center(80, "-"))
 
-        with open(motd, encoding="utf-8") as file:
+        with open(self._path, encoding="utf-8") as file:
             for line in file:
                 tf2mon.ui.show_journal("help", line.strip())
