@@ -8,11 +8,11 @@ from tf2mon.player import Player
 class KickLastControl(Control):
     """Kick last killer."""
 
-    name = None
-    attr = None
+    name: str = None
+    attr: str = None
 
     def handler(self, _match) -> None:
-        tf2mon.monitor.kick_my_last_killer(self.attr)
+        tf2mon.users.kick_my_last_killer(self.attr)
 
     def status(self) -> str:
         return self.attr
