@@ -11,13 +11,12 @@ class UserPanelControl(Control):
     """Cycle contents of User Panel."""
 
     name = "TOGGLE-USER-PANEL"
-    enum = Enum(f"_e_{name}", "AUTO DUELS KICKS SPAMS")
-    toggle = Toggle(f"_t_{name}", enum)
+    enum = Enum("_e_user_panel", "AUTO DUELS KICKS SPAMS")
+    toggle = Toggle("_t_user_panel", enum)
 
     def handler(self, _match) -> None:
-        if tf2mon.monitor.toggling_enabled:
-            _ = self.toggle.toggle
-            tf2mon.ui.update_display()
+        _ = self.toggle.toggle
+        tf2mon.ui.update_display()
 
     def status(self) -> str:
         return self.toggle.value.name
