@@ -1,7 +1,9 @@
 import re
 
+from loguru import logger
+
 import tf2mon
-from tf2mon.game import GameEvent
+from tf2mon.gameevent import GameEvent
 
 
 class GameConnectedEvent(GameEvent):
@@ -10,10 +12,10 @@ class GameConnectedEvent(GameEvent):
 
     def handler(self, match: re.Match) -> None:
 
-        _leader, username = match.groups()
+        (username,) = match.groups()
 
-        tf2mon.logger.log("CONNECT", tf2mon.monitor.users[username])
+        logger.log("CONNECT", tf2mon.users[username])
 
         tf2mon.ui.notify_operator = True
         if username == tf2mon.config.get("player_name"):
-            tf2mon.monitor.reset_game()
+            tf2mon.reset_game()
