@@ -6,12 +6,13 @@ import os
 import sys
 
 import libcurses
+from libcurses.bw import BorderedWindow
 from loguru import logger
 
 import tf2mon
 from tf2mon.baselayout import BaseLayout
 from tf2mon.scoreboard import Scoreboard
-from tf2mon.user import Team, UserState
+from tf2mon.user import Team
 
 # from playsound import playsound
 
@@ -19,6 +20,8 @@ from tf2mon.user import Team, UserState
 class UI:
     """User Interface."""
 
+    # pylint: disable=too-many-instance-attributes
+
     def __init__(self, win: curses.window):
         """Initialize User Interface."""
 
@@ -48,13 +51,15 @@ class UI:
             self.colormap[Team.RED.name],
         )
 
+        self.popup_win: curses.window = None
+
     def build_grid(self) -> None:
         """Add boxes to grid.
 
         Called at init, on KEY_RESIZE events, and when layout changes.
         """
 
-        klass = tf2mon.controls["GridLayoutControl"].value
+        klass = tf2mon.GridLayoutControl.value
         try:
             self.layout = klass(self.grid)
         except AssertionError:
@@ -96,7 +101,8 @@ class UI:
             self.layout.cmdline_win.scrollok(True)
             self.layout.cmdline_win.keypad(True)
 
-        self.refresh_chats()
+        if tf2mon.ui is not None:
+            tf2mon.ChatsControl.refresh()
         self.grid.redraw()
 
     def getline(self, prompt=None):
@@ -121,25 +127,14 @@ class UI:
 
         self.refresh_kicks()
         self.refresh_spams()
-        self.refresh_duels(tf2mon.monitor.me)
-        self.refresh_user(tf2mon.monitor.me)
+        self.refresh_duels(tf2mon.users.me)
+        self.refresh_user(tf2mon.users.me)
         # chatwin_blu and chatwin_red are rendered from gameplay/_playerchat
         self.scoreboard.refresh()
         self.show_status()
-        self.grid.refresh()
 
-    def refresh_chats(self):
-        """Refresh chat panel(s)."""
-
-        for win in [
-            self.layout.chatwin_blu,
-            self.layout.chatwin_red,
-        ]:
-            if win:
-                win.erase()
-
-        for chat in tf2mon.monitor.chats:
-            self.show_chat(chat)
+        if self.popup_win:
+            self.popup_win.refresh()
 
     def refresh_kicks(self):
         """Refresh kicks panel."""
@@ -147,12 +142,12 @@ class UI:
         if self.layout.kicks_win:
             self._show_lines(
                 "KICKS",
-                reversed(tf2mon.controls["KicksControl"].msgs),
+                reversed(tf2mon.KicksControl.msgs),
                 self.layout.kicks_win,
             )
 
         if self.layout.user_win:
-            self.refresh_user(tf2mon.monitor.me)
+            self.refresh_user(tf2mon.users.me)
 
     def refresh_spams(self):
         """Refresh spams panel."""
@@ -160,12 +155,12 @@ class UI:
         if self.layout.spams_win:
             self._show_lines(
                 "SPAMS",
-                reversed(tf2mon.controls["SpamsControl"].msgs),
+                reversed(tf2mon.SpamsControl.msgs),
                 self.layout.spams_win,
             )
 
         if self.layout.user_win:
-            self.refresh_user(tf2mon.monitor.me)
+            self.refresh_user(tf2mon.users.me)
 
     def refresh_duels(self, user):
         """Refresh duels panel."""
@@ -174,14 +169,14 @@ class UI:
             self._show_lines("user", self._format_duels(user), self.layout.duels_win)
 
         if self.layout.user_win:
-            self.refresh_user(tf2mon.monitor.me)
+            self.refresh_user(tf2mon.users.me)
 
     def refresh_user(self, user):
         """Refresh user panel."""
 
-        panel = tf2mon.controls["UserPanelControl"]
-        kicks = tf2mon.controls["KicksControl"]
-        spams = tf2mon.controls["SpamsControl"]
+        panel = tf2mon.UserPanelControl
+        kicks = tf2mon.KicksControl
+        spams = tf2mon.SpamsControl
 
         if self.layout.user_win:
             if panel.value == panel.enum.KICKS or (
@@ -213,10 +208,10 @@ class UI:
         if user.display_level:
             color = self.colormap[user.display_level]
 
-        if user == tf2mon.monitor.my.last_killer:
+        if user == tf2mon.users.my.last_killer:
             color |= curses.A_BOLD | curses.A_ITALIC
 
-        if user == tf2mon.monitor.my.last_victim:
+        if user == tf2mon.users.my.last_victim:
             color |= curses.A_BOLD
 
         if user.selected:
@@ -241,14 +236,23 @@ class UI:
         if not win:
             return  # not showing chats
 
-        color = self.colormap[chat.user.team.name if chat.user.team else "user"]
+        user = chat.user
+        color = self.colormap[user.team.name if user.team else "user"]
         if chat.teamflag:
             color |= curses.A_UNDERLINE
+        user_color = self.user_color(user, color)
 
+        leader = f"{chat.s_timestamp}: {chat.user.username:20.20}: "
         if sum(win.getyx()):
             win.addch("\n")
-        line = f"{chat.seqno}: {chat.user.username:20.20}: {chat.msg}"
-        win.addstr(line, self.user_color(chat.user, color))
+        win.addstr(leader + chat.msg, user_color)
+
+        if tf2mon.ShowKillsControl.value and chat.msg != "/rtd":
+            # self._show_last_duels(win, leader, user, user_color)
+            indent = " " * 15
+            for line in chat.user.format_user_stats():
+                win.addstr(f"\n{leader}{indent}{line}")
+
         win.noutrefresh()
 
     def show_journal(self, level: str, line: str) -> None:
@@ -262,22 +266,26 @@ class UI:
         win.addstr(line, self.colormap[level])
         win.noutrefresh()
 
+    def popup(self, level: str, text: str) -> None:
+        """Display `text` in a popup window."""
+
+        self.popup_win = BorderedWindow(
+            self.grid.nlines - 10,
+            80,
+            self.grid.begin_y + 5,
+            self.grid.begin_x + 20,
+        )
+        # self.popup_win.box()
+        # self.popup_win.scrollok(True)
+        self.popup_win.w.addstr(text, self.colormap[level])
+        self.popup_win.refresh()
+
     def show_player_intel(self, player) -> None:
         """Display what we know about `player`."""
 
         level = player.display_level
         leader = f"{level}: {player.steamid}"
 
-        # self.show_journal(
-        #     "Player",
-        #     f"{leader}: {player}",
-        # )
-
-        # self.show_journal(
-        #     level,
-        #     f"{leader}: {player.astuple()}",
-        # )
-
         self.show_journal(
             level,
             f"{leader}: name: `{player.last_name}`",
@@ -306,7 +314,7 @@ class UI:
         indent = " " * 12  # 12=len("99 and 99 vs")
 
         lines.append("Duels:")
-        for opponent in [x for x in user.opponents.values() if x.state == UserState.ACTIVE]:
+        for opponent in [x for x in user.opponents.values() if x.is_active]:
             lines.append(f"{user.duel_as_str(opponent, True)} vs {opponent.moniker}")
 
             if opponent.key in user.nkills_by_opponent_by_weapon:
@@ -322,7 +330,7 @@ class UI:
     def show_status(self):
         """Update status line."""
 
-        line = tf2mon.controls.get_status_line() + f" UID={tf2mon.monitor.my.userid}"
+        line = tf2mon.controller.get_status_line() + f" UID={tf2mon.users.my.userid}"
 
         try:
             self.layout.status_win.addstr(
